Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Handler ¶
Handler form files to the format provided by form. Process request steps:
- Retrieve userinput format from URL
- Use http.MaxBytesReader to avoid memory abuse
- Parse output configuration
- Create temp file
- Run conversion
- Send result file
func Run ¶
func Run(ctx context.Context, bufferSize int, pump pipe.SourceAllocatorFunc, sink pipe.SinkAllocatorFunc) error
Run encoding using Pump as the source and Sinks as destination.
Types ¶
type Form ¶
Form provides user-input for http encoding.
type Input ¶
type Input struct {
*fileformat.Format
multipart.File
}
Input is user-provided input for encoding.
type Output ¶
type Output struct {
*fileformat.Format
Sink func(io.WriteSeeker) pipe.SinkAllocatorFunc
}
Output is user-provided output for encoding.
Source Files
¶
- handler.go
- pipe.go
Click to show internal directories.
Click to hide internal directories.